@@ -38,8 +38,13 @@ class NotFoundError(Exception):
 nothing = object()
 
 
+# Use compiled regex pattern for speed up since
+# this regex pattern is used thousands of times.
+strip_uuid_from_comment_search_pattern = re.compile(r"<uuid:([a-z0-9-]+)>")
+
+
 def strip_uuid_from_comment(comment):
-    match = re.search(r"<uuid:([a-z0-9-]+)>", comment)
+    match = strip_uuid_from_comment_search_pattern.search(comment)
 
     if match is None:
         return comment, None
@@ -57,8 +62,13 @@ class ReadWrite:
     writable = attr.ib()
 
 
+# Use compiled regex pattern for speed up since
+# this regex pattern is used thousands of times.
+strip_rw_from_comment_search_pattern = re.compile(r"<rw:([01]):([01])>")
+
+
 def strip_rw_from_comment(comment):
-    match = re.search(r"<rw:([01]):([01])>", comment)
+    match = strip_rw_from_comment_search_pattern.search(comment)
 
     if match is None:
         return comment, None
@@ -422,6 +432,10 @@ class Signal:
                     )
                 )
 
+            # Check pack_bitstring ahead of time. If this fails with an UnableToPackError exception, then the value
+            # cannot be set and is invalid. Checking here prevents an endless loop of error message dialogs.
+            self.pack_bitstring(value)
+
         return True
 
     def set_value(
@@ -789,7 +803,10 @@ class Frame(QtCanListener):
             data = self.data
 
         return can.Message(
-            extended_id=self.extended, arbitration_id=self.id, dlc=self.size, data=data
+            is_extended_id=self.extended,
+            arbitration_id=self.id,
+            dlc=self.size,
+            data=data,
         )
 
     def message_received(self, msg):
