@@ -10,6 +10,7 @@ import attr
 import can
 import canmatrix.formats
 import collections
+import copy
 import decimal
 import epyqlib.canneo
 import epyqlib.deviceextension
@@ -96,6 +97,7 @@ class Elements(Enum):
     scripting = 6
     fault_log = 7
     files = 8
+    information = 9
 
 
 @unique
@@ -107,6 +109,7 @@ class Tabs(Enum):
     scripting = 5
     fault_log = 6
     files = 7
+    information = 8
 
     @classmethod
     def defaults(cls):
@@ -227,6 +230,8 @@ class Device:
     def __init__(self, *args, **kwargs):
         self.bus = None
         self.from_zip = False
+        self.device_sha = "N/A"
+        self.device_file = "N/A"
 
         if kwargs.get("file", None) is not None:
             constructor = self._init_from_file
@@ -291,6 +296,7 @@ class Device:
             self.bus.set_bus()
 
     def _init_from_file(self, file, only_for_files=False, **kwargs):
+        self.device_file = file
         extension = os.path.splitext(file)[1].casefold()
 
         if extension in (".epz", ".zip"):
@@ -429,6 +435,9 @@ class Device:
         if Tabs.files not in tabs:
             self.elements.discard(Elements.files)
 
+        if Tabs.information not in tabs:
+            self.elements.discard(Elements.information)
+
         self.elements |= depended_on
 
         self.referenced_files = [
@@ -445,7 +454,7 @@ class Device:
             if f is not None
         ]
 
-        self.shas = []
+        self.compatibility_shas = []
         compatibility_file = d.get("compatibility", None)
         if compatibility_file is not None:
             compatibility_file = os.path.join(
@@ -455,7 +464,7 @@ class Device:
                 s = file.read()
                 c = json.loads(s, object_pairs_hook=OrderedDict)
 
-            self.shas.extend(c.get("shas", []))
+            self.compatibility_shas.extend(c.get("shas", []))
 
         if not only_for_files:
             self.can_path = os.path.join(path, d["can_path"])
@@ -529,26 +538,32 @@ class Device:
                     break
 
         # TODO error dialog if no .epc found in zip file
-        filename = None
+        filename_epc = None
+        filename_sha = None
         for directory, directories, files in os.walk(path):
             for f in files:
                 logger.info(f)
                 if os.path.splitext(f)[1] == ".epc":
-                    filename = os.path.join(path, directory, f)
-                    break
+                    filename_epc = os.path.join(path, directory, f)
+                elif f == "sha":
+                    filename_sha = os.path.join(path, directory, f)
 
-            if filename is not None:
+            if filename_epc is not None and filename_sha is not None:
                 break
 
-        self.config_path = os.path.abspath(filename)
+        if filename_sha is not None:
+            with open(filename_sha, "r") as f:
+                self.device_sha = f.readline().strip()
+
+        self.config_path = os.path.abspath(filename_epc)
 
         converted_directory = None
-        if not epyqlib.updateepc.is_latest(filename):
+        if not epyqlib.updateepc.is_latest(filename_epc):
             converted_directory = tempfile.TemporaryDirectory()
-            file = epyqlib.updateepc.convert(filename, converted_directory.name)
+            file = epyqlib.updateepc.convert(filename_epc, converted_directory.name)
             self.config_path = os.path.abspath(file)
 
-        with open(filename, "r") as f:
+        with open(filename_epc, "r") as f:
             self._load_config(f, rx_interval=rx_interval, **kwargs)
 
         if converted_directory is not None:
@@ -641,10 +656,12 @@ class Device:
 
         notifiees = []
 
+        # Load the matrix once and use as needed as a speed optimization.
+        matrix = load_matrix(self.can_path)
+
         if Elements.dash in self.elements:
             self.uis = self.dash_uis
 
-            matrix = load_matrix(self.can_path)
             # TODO: this is icky
             if Elements.tx not in self.elements:
                 self.neo_frames = epyqlib.canneo.Neo(
@@ -655,9 +672,8 @@ class Device:
 
         if Elements.rx in self.elements:
             # TODO: the repetition here is not so pretty
-            matrix_rx = load_matrix(self.can_path)
             neo_rx = epyqlib.canneo.Neo(
-                matrix=matrix_rx,
+                matrix=matrix,
                 frame_class=epyqlib.txrx.MessageNode,
                 signal_class=epyqlib.txrx.SignalNode,
                 node_id_adjust=self.node_id_adjust,
@@ -674,13 +690,12 @@ class Device:
             rx.end_insert_rows.connect(rx_model.end_insert_rows)
 
         if Elements.tx in self.elements:
-            matrix_tx = load_matrix(self.can_path)
             message_node_tx_partial = functools.partial(
                 epyqlib.txrx.MessageNode, tx=True
             )
             signal_node_tx_partial = functools.partial(epyqlib.txrx.SignalNode, tx=True)
             neo_tx = epyqlib.canneo.Neo(
-                matrix=matrix_tx,
+                matrix=matrix,
                 frame_class=message_node_tx_partial,
                 signal_class=signal_node_tx_partial,
                 node_id_adjust=self.node_id_adjust,
@@ -718,9 +733,8 @@ class Device:
 
         self.widget_nvs = None
         if Elements.nv in self.elements:
-            matrix_nv = load_matrix(self.can_path)
             self.frames_nv = epyqlib.canneo.Neo(
-                matrix=matrix_nv,
+                matrix=matrix,
                 frame_class=epyqlib.nv.Frame,
                 signal_class=epyqlib.nv.Nv,
                 node_id_adjust=self.node_id_adjust,
@@ -803,7 +817,7 @@ class Device:
                             )
 
             self.widget_frames_nv = epyqlib.canneo.Neo(
-                matrix=matrix_nv,
+                matrix=matrix,
                 frame_class=epyqlib.nv.Frame,
                 signal_class=epyqlib.nv.Nv,
                 node_id_adjust=self.node_id_adjust,
@@ -929,6 +943,8 @@ class Device:
             self.ui.tabs.removeTab(self.ui.tabs.indexOf(self.ui.faultlog))
         if Tabs.files not in tabs:
             self.ui.tabs.removeTab(self.ui.tabs.indexOf(self.ui.files))
+        if Tabs.information not in tabs:
+            self.ui.tabs.removeTab(self.ui.tabs.indexOf(self.ui.information))
 
         self.ui.tabs.setCurrentIndex(0)
 
@@ -1076,9 +1092,8 @@ class Device:
                                 action[0](dash=dash, widget=widget, signal=widget.edit)
                                 break
 
-        monitor_matrix = load_matrix(self.can_path)
         monitor_frames = epyqlib.canneo.Neo(
-            matrix=monitor_matrix,
+            matrix=matrix,
             node_id_adjust=self.node_id_adjust,
         )
         monitor_frame = monitor_frames.frame_by_name(
@@ -1098,7 +1113,7 @@ class Device:
 
         notifiees.append(self.connection_monitor)
 
-        self.bus_status_changed(online=False, transmit=False)
+        self.bus_status_changed(online=False, transmit=False, skip_set_stale=True)
 
         all_signals = set()
         for frame in self.neo_frames.frames:
@@ -1163,6 +1178,12 @@ class Device:
         if Tabs.files in tabs:
             self.ui.files_view.set_device_interface(self.device_interface)
 
+        if Tabs.information in tabs:
+            self.ui.information_text_browser.append(f"Name:\t\t{self.name}")
+            self.ui.information_text_browser.append(f"Type:\t\t{self.node_id_type}")
+            self.ui.information_text_browser.append(f"SHA:\t\t{self.device_sha}")
+            self.ui.information_text_browser.append(f"File:\t\t{self.device_file}")
+
         self.notifiees = notifiees
         for notifiee in notifiees:
             self.bus.notifier.add(notifiee)
@@ -1194,8 +1215,8 @@ class Device:
     def get_frames(self):
         return self.frames
 
-    @pyqtSlot(bool)
-    def bus_status_changed(self, online, transmit):
+    @pyqtSlot(bool, bool, bool)
+    def bus_status_changed(self, online, transmit, skip_set_stale=False):
         self.bus_online = online
         self.bus_tx = transmit
 
@@ -1214,9 +1235,10 @@ class Device:
 
         self.read_nv_widget_min_max()
 
-        if self.nvs is not None:
-            if not online:
-                self.nvs.set_stale()
+        if not skip_set_stale:
+            if self.nvs is not None:
+                if not online:
+                    self.nvs.set_stale()
 
         if self.ui.tabs.indexOf(self.ui.files) != -1:
             self.ui.files_view.on_bus_status_changed()
